ARTICLE_WEIGHT = 0.75


FOREX_TICKERS = [
    "EURUSD=X",
    "JPY=X",
    "GBPUSD=X",
    "EURJPY=X",
    "EURGBP=X",
    "AUDUSD=X",
    "NZDUSD=X",
    "GBPJPY=X",
    "EURCAD=X",
    "EURSEK=X",
    "EURCHF=X",
    "EURHUF=X",
    "EURJPY=X",
    "CNY=X",
    "HKD=X",
    "SGD=X",
    "INR=X",
    "MXN=X",
    "PHP=X",
    "THB=X",
    "ZAR=X",
    "RUB=X",
]
